# `synapse` listener config

Synapse serves endpoints under so-called listeners, which are
defined in `synapse_listeners_config`. The role gives some pre-
configured options to set for use in various scenarios.

## Behind reverse proxy which does SSL offloading

The `synapse_listeners_default_config` is analog to the upstream
defaults and will serve both federation and client API on a
single HTTP port, without TLS or compression, while trusting the
`X-Forwarded-For` headers.

Use it like this:
```yaml
synapse_listeners_config: "{{ synapse_listeners_default_config }}"
# Change the port like this
synapse_config_listeners_port: 8090
# If you use docker or your reverse-proxy is not local,
# set the listen_addresses like this
synapse_config_listeners_bind_addresses:
  - "::"
  - "0.0.0.0"
```

### Additional local metrics listener

The role provides a ready-to-use configuration for a locally-reachable
metrics listener in `synapse_metrics_listener`.

To enable it, set `synapse_config_listeners: "{{ synapse_listeners_default_config + synapse_metrics_listener}}`.

To customize the listener, see [the `synapse_config_metrics_listener_*` variables
in `defaults/main/homeserver.listeners.yml`](../defaults/main/homeserver.listeners.yml).

The defaults will create a http-only metrics listener on port 9000 which
will listen on `127.0.0.1` and `::1`.

## Synapse handling TLS without reverse proxy

Supply your certificates using `synapse_config_tls_{certificate,private_key}_path`.

Then you can either customize the default listener like this:
```yaml
# synapse_config_tls_certificate_path: "/etc/ssl/{{ synapse_domain }}.pem"
# synapse_config_tls_private_key_path: "/etc/ssl/{{ synapse_domain }}.key"
synapse_config_listeners_port: 443
synapse_config_listeners_tls: true
synapse_config_listeners_type: https
synapse_config_listeners_x_forwarded: false
synapse_config_listeners_resources_compress: true
synapse_config_serve_server_wellknown: true
```

or you can serve federation over a different port, by completely rewriting
the role's defaults:
```yaml
synapse_config_listeners:
  - port: 8448
    tls: true
    type: https
    x_forwarded: true
    bind_addresses:
      - 10.0.0.1
      - fd00::1
    resources:
      - names: federation
        compress: true
  - port: 443
    tls: true
    type: https
    x_forwarded: true
    bind_addresses:
      - 10.0.0.2
      - fd00::2
    resources:
      - names: client
        compress: true
```

It is possible to mix and match those listeners to almost all requirements,
like listening locally without HTTPs for federation and using a WAF / firewall /
reverse proxy infront of synapse for federation (see: "Secure Border Gateways")
and trusting the `X-Forwarded-For` Header, while having clients
directly connect to synapse.
